@@ -19,7 +19,7 @@
 # THE SOFTWARE.
 
 from ansiblelint import AnsibleLintRule
-from ansiblelint.utils import LINE_NUMBER_KEY, FILENAME_KEY
+from ansiblelint.utils import LINE_NUMBER_KEY, FILENAME_KEY, get_first_cmd_arg
 
 
 class EnvVarsInCommandRule(AnsibleLintRule):
@@ -38,10 +38,10 @@ class EnvVarsInCommandRule(AnsibleLintRule):
                      LINE_NUMBER_KEY, FILENAME_KEY]
 
     def matchtask(self, file, task):
-        if task["action"]["__ansible_module__"] in ['shell', 'command']:
-            if 'cmd' in task['action']:
-                first_cmd_arg = task['action']['cmd'].split()[0]
-            else:
-                first_cmd_arg = task['action']['__ansible_arguments__'][0]
+        if task["action"]["__ansible_module__"] in ['command']:
+            first_cmd_arg = get_first_cmd_arg(task)
+            if not first_cmd_arg:
+                return
+
             return any([arg not in self.expected_args for arg in task['action']] +
                        ["=" in first_cmd_arg])
